% linear vs nonlinear: nonlinear
% Xiaochuan Xing
% Beijing, January, 2015

%----------------------------------------------------------------
% 0. Housekeeping (close all graphic windows)
%----------------------------------------------------------------

close all;

%----------------------------------------------------------------
% 1. Defining variables
%----------------------------------------------------------------

var Y K C A;
varexo ea;

predetermined_variables K;

parameters alpha $\alpha$ beta $\beta$ delta $\delta$ rho $\rho$ sk si sc;

%----------------------------------------------------------------
% 2. Calibration
%----------------------------------------------------------------

alpha=0.4;
beta=0.99;
delta=0.025;
rho=0.9;

sk=alpha*beta/(1-beta*(1-delta));
si=delta*sk;
sc=1-si;

%----------------------------------------------------------------
% 3. Model
%----------------------------------------------------------------

model;
1/C=beta*(1/C(+1))*(alpha*Y(+1)/K(+1)+1-delta);
C+K(+1)-(1-delta)*K=Y;
Y=A*(K^alpha);
log(A)=rho*log(A(-1))+ea;
end;

%----------------------------------------------------------------
% 4. Steasy State
%----------------------------------------------------------------

steady_state_model;
A=1;
Y=sk^(alpha/(1-alpha));
K=sk*Y;
C=sc*Y;
end;

//use command to generate TeX-Files with dynamic and static model equations
write_latex_dynamic_model;
write_latex_static_model;

%----------------------------------------------------------------
% 5. Computation
%----------------------------------------------------------------

steady;

check;

shocks;
var ea=1;
end;

stoch_simul(irf=100,order=1,periods=200);
datatomfile('simudatanl',[]);