% linear vs nonlinear: nonlinear
% Xiaochuan Xing
% Beijing, January, 2015

%----------------------------------------------------------------
% 0. Housekeeping (close all graphic windows)
%----------------------------------------------------------------

close all;

%----------------------------------------------------------------
% 1. Defining variables
%----------------------------------------------------------------

var y k c a;
varexo ea;

predetermined_variables k;

parameters alpha $\alpha$ beta $\beta$ delta $\delta$ rho $\rho$ sk si sc;

%----------------------------------------------------------------
% 2. Calibration
%----------------------------------------------------------------

alpha=0.4;
beta=0.99;
delta=0.025;
rho=0.9;

sk=alpha*beta/(1-beta*(1-delta));
si=delta*sk;
sc=1-si;

%----------------------------------------------------------------
% 3. Model
%----------------------------------------------------------------

model(linear);
-c=-c(+1)+(1-beta*(1-delta))*(y(+1)-k(+1));
y=a+alpha*k;
sc*c+sk*k(+1)-(1-delta)*sk*k=y;
a=rho*a(-1)+ea;
end;

%----------------------------------------------------------------
% 4. Steasy State
%----------------------------------------------------------------

steady_state_model;
a=0;
y=0;
k=0;
c=0;
end;

//use command to generate TeX-Files with dynamic and static model equations
write_latex_dynamic_model;
write_latex_static_model;

%----------------------------------------------------------------
% 5. Computation
%----------------------------------------------------------------

steady;

check;

shocks;
var ea=1;
end;

stoch_simul(irf=100,order=1,periods=200);
datatomfile('simudatanl',[]);